﻿using ProjectSession.Entities.Enums;
using ProjectSession.Entities;
using ProjectSession.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectSession.Forms;

public partial class AddMarkForm : Form
{
    private readonly IAddMarkRepository _addMarkRepository;
    private readonly IStudentRepository _studentRepository;
    private readonly IGroupRepository _groupRepository;
    private readonly ITeacherRepository _teacherRepository;
    private readonly IDisciplineRepository _disciplineRepository;

    public AddMarkForm(IAddMarkRepository addMarkRepository, IStudentRepository studentRepository, IGroupRepository groupRepository, ITeacherRepository teacherRepository, IDisciplineRepository disciplineRepository)
    {
        InitializeComponent();

        _addMarkRepository = addMarkRepository ?? throw new ArgumentNullException(nameof(addMarkRepository));
        _studentRepository = studentRepository ?? throw new ArgumentNullException(nameof(studentRepository));
        _groupRepository = groupRepository ?? throw new ArgumentNullException(nameof(groupRepository));
        _teacherRepository = teacherRepository ?? throw new ArgumentNullException(nameof(teacherRepository));
        _disciplineRepository = disciplineRepository ?? throw new ArgumentNullException(nameof(disciplineRepository));


        comboBoxStudent.DataSource = _studentRepository.GetAllStudents();
        comboBoxStudent.DisplayMember = "Name";
        comboBoxStudent.ValueMember = "Id";

        comboBoxGroup.DataSource = _groupRepository.GetAllGroups();
        comboBoxGroup.DisplayMember = "Name";
        comboBoxGroup.ValueMember = "Id";

        comboBoxTeacher.DataSource = _teacherRepository.GetAllTeachers();
        comboBoxTeacher.DisplayMember = "Name";
        comboBoxTeacher.ValueMember = "Id";

        comboBoxDiscipline.DataSource = _disciplineRepository.GetAllDisciplines();
        comboBoxDiscipline.DisplayMember = "Name";
        comboBoxDiscipline.ValueMember = "Id";

        comboBoxMark.DataSource = Enum.GetValues(typeof(Mark));


        dateTimePickerDate.Enabled = false;
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (comboBoxStudent.SelectedIndex < 0 ||
                comboBoxGroup.SelectedIndex < 0 ||
                comboBoxTeacher.SelectedIndex < 0 ||
                comboBoxDiscipline.SelectedIndex < 0 ||
                comboBoxMark.SelectedIndex < 0)
            {
                throw new Exception("Имеются незаполненные поля");
            }

            _addMarkRepository.CreateMark(AddMark.CreateOperation(0,
                (int)comboBoxStudent.SelectedValue!,
                (int)comboBoxGroup.SelectedValue!,
                (int)comboBoxDiscipline.SelectedValue!,
                (Mark)comboBoxMark.SelectedItem!));

            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e) => Close();
}
