﻿using ProjectSession.Entities.Enums;
using ProjectSession.Entities;
using ProjectSession.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectSession.Forms;

public partial class DisciplineForm : Form
{
    private readonly IDisciplineRepository _disciplineRepository;
    private int? _disciplineId;

    public int Id
    {
        set
        {
            try
            {
                var discipline = _disciplineRepository.GetDisciplineById(value);
                if (discipline == null)
                {
                    throw new InvalidDataException(nameof(discipline));
                }
                foreach (Course elem in Enum.GetValues(typeof(Course)))
                {
                    if ((elem & discipline.Courses) != 0)
                    {
                        checkedListBoxCourse.SetItemChecked(checkedListBoxCourse.Items.IndexOf(elem), true);
                    }
                }
                textBoxName.Text = discipline.Name;
                textBoxDescription.Text = discipline.Description;
                _disciplineId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }

    public DisciplineForm(IDisciplineRepository disciplineRepository)
    {
        InitializeComponent();

        _disciplineRepository = disciplineRepository ?? throw new ArgumentNullException(nameof(disciplineRepository));

        foreach (var elem in Enum.GetValues(typeof(Course)))
        {
            checkedListBoxCourse.Items.Add(elem);
        }
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxName.Text) ||
                string.IsNullOrWhiteSpace(textBoxDescription.Text) ||
                checkedListBoxCourse.CheckedItems.Count == 0)
            {
                throw new Exception("Имеются незаполненные поля");
            }

            if (_disciplineId.HasValue)
            {
                _disciplineRepository.UpdateDiscipline(CreateDiscipline(_disciplineId.Value));
            }
            else
            {
                _disciplineRepository.AddDiscipline(CreateDiscipline(0));
            }

            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e) => Close();

    private Discipline CreateDiscipline(int id)
    {
        Course course = Course.None;
        foreach (var elem in checkedListBoxCourse.CheckedItems)
        {
            course |= (Course)elem;
        }
        return Discipline.Create(id, textBoxName.Text, textBoxDescription.Text, course);
    }
}