﻿using ProjectSession.Entities.Enums;
using ProjectSession.Entities;
using ProjectSession.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectSession.Forms;

public partial class GroupForm : Form
{
    private readonly IGroupRepository _groupRepository;
    private int? _groupId;

    public int Id
    {
        set
        {
            try
            {
                var group = _groupRepository.GetGroupById(value);
                if (group == null)
                {
                    throw new InvalidDataException(nameof(group));
                }
                textBoxName.Text = group.Name;
                comboBoxType.SelectedItem = group.Type;
                _groupId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }

    public GroupForm(IGroupRepository groupRepository)
    {
        InitializeComponent();
        _groupRepository = groupRepository ??
            throw new ArgumentNullException(nameof(groupRepository));

        comboBoxType.DataSource = Enum.GetValues(typeof(GroupType));
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxName.Text) || comboBoxType.SelectedIndex < 0)
            {
                throw new Exception("Имеются незаполненные поля");
            }

            if (_groupId.HasValue)
            {
                _groupRepository.UpdateGroup(CreateGroup(_groupId.Value));
            }
            else
            {
                _groupRepository.AddGroup(CreateGroup(0));
            }

            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e) => Close();

    private Group CreateGroup(int id) => Group.
        Create(id, textBoxName.Text,
        (GroupType)comboBoxType.SelectedItem!);
}
