﻿using ProjectSession.Entities;
using ProjectSession.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectSession.Forms;

public partial class StudentForm : Form
{
    private readonly IStudentRepository _studentRepository;
    private int? _studentId;

    public int Id
    {
        set
        {
            try
            {
                var student = _studentRepository.GetStudentById(value);
                if (student == null)
                {
                    throw new InvalidDataException(nameof(student));
                }
                textBoxSurname.Text = student.Surname;
                textBoxName.Text = student.Name;
                textBoxMiddleName.Text = student.MiddleName;
                comboBoxGroup.SelectedValue = student.GroupID;
                _studentId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }

    public StudentForm(IStudentRepository studentRepository)
    {
        InitializeComponent();
        _studentRepository = studentRepository ??
            throw new ArgumentNullException(nameof(studentRepository));
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxSurname.Text) ||
                string.IsNullOrWhiteSpace(textBoxName.Text) ||
                string.IsNullOrWhiteSpace(textBoxMiddleName.Text) ||
                comboBoxGroup.SelectedItem == null)
            {
                throw new Exception("Имеются незаполненные поля");
            }

            if (_studentId.HasValue)
            {
                _studentRepository.UpdateStudent(CreateStudent(_studentId.Value));
            }
            else
            {
                _studentRepository.AddStudent(CreateStudent(0));
            }

            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }

    }

    private void ButtonCancel_Click(object sender, EventArgs e) => Close();

    private Student CreateStudent(int id) => Student.Create(
        id,
        textBoxSurname.Text,
        textBoxName.Text,
        textBoxMiddleName.Text,
        (int)comboBoxGroup.SelectedValue!);
}
