﻿using ProjectSession.Entities;
using ProjectSession.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectSession.Forms;

public partial class TeacherForm : Form
{

    private readonly ITeacherRepository _teacherRepository;
    private int? _teacherId;

    public int Id
    {
        set
        {
            try
            {
                var teacher = _teacherRepository.GetTeacherById(value);
                if (teacher == null)
                {
                    throw new InvalidDataException(nameof(teacher));
                }
                textBoxSurname.Text = teacher.Surname;
                textBoxName.Text = teacher.Name;
                textBoxMiddleName.Text = teacher.MiddleName;
                comboBoxDiscipline.SelectedValue = teacher.DisciplineID;
                _teacherId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }

    public TeacherForm(ITeacherRepository teacherRepository)
    {
        InitializeComponent();
        _teacherRepository = teacherRepository ?? throw new ArgumentNullException(nameof(teacherRepository));
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxSurname.Text) ||
                string.IsNullOrWhiteSpace(textBoxName.Text) ||
                string.IsNullOrWhiteSpace(textBoxMiddleName.Text))
            {
                throw new Exception("Имеются незаполненные поля");
            }

            if (_teacherId.HasValue)
            {
                _teacherRepository.UpdateTeacher(CreateTeacher(_teacherId.Value));
            }
            else
            {
                _teacherRepository.AddTeacher(CreateTeacher(0));
            }

            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e) => Close();

    private Teacher CreateTeacher(int id) => Teacher.Create(
        id,
        textBoxSurname.Text,
        textBoxName.Text,
        textBoxMiddleName.Text,
        (int)comboBoxDiscipline.SelectedValue!);
}
